@@ -9,10 +9,12 @@
 from typing import List
 from aiohttp import ClientSession
 from os import path, listdir, makedirs
-
+from .request import fetch_user_info
+from .assets import StaticPath
 from nonebot import get_driver
 from .config import Config
 from nonebot.log import logger
+import ujson as json
 
 try:
     plugin_config = Config.parse_obj(get_driver().config)
@@ -41,7 +43,7 @@ async def check_song_update() -> List[str]:
             return result
 
 
-async def check_char_update() -> int:
+async def check_char_update() -> List[str]:
     async with ClientSession() as session:
         async with session.get(src_api_url+"char_list", verify_ssl=False) as resp:
             result = list()
@@ -52,3 +54,9 @@ async def check_char_update() -> int:
                             file.write(await res.read())
                             result.append(k)
             return result
+
+
+async def check_constants_update():
+    res = await fetch_user_info("constants")
+    with open(StaticPath.constants_json, "w", encoding="UTF-8") as f:
+        f.write(json.dumps(res, indent=4))
\ No newline at end of file
